// guideScreen.js

import { StatusBar } from 'expo-status-bar';
import React from 'react';
import { render } from 'react-dom';
import { StyleSheet, 
        Text, 
        View, 
        Image, 
        ScrollView, 
        TouchableOpacity, 
        Animated, 
        Platform, 
        Button, } from 'react-native';
import {colors, appLogo, fontStyles, pageTitle, appLogoContainer, page} from './styles/themes';
import { Audio } from 'expo-av';
import { Ionicons } from '@expo/vector-icons';
import moment from 'moment';

//resources: 
// https://morioh.com/p/ed71cad8a8c9
// https://docs.expo.io/versions/v39.0.0/sdk/audio/#audiosound
// https://www.youtube.com/watch?v=HCvp2fZh--A

export default class guideScreen extends React.Component {
    state = {
        isPlaying: false,
        playbackInstance: null,
        currentIndex: 0,
        volume: 1.0,
        isBuffering: false
    }

    async componentDidMount() {
        try {
            await Audio.setAudioModeAsync({
            allowsRecordingIOS: false,
            interruptionModeIOS: Audio.INTERRUPTION_MODE_IOS_DO_NOT_MIX,
            playsInSilentModeIOS: true,
            interruptionModeAnrdoid: Audio.INTERRUPTION_MODE_ANDROID_DUCK_OTHERS,
            shouldDuckAndroid: true,
            staysActiveInBackground: true,
            playThroughEarpieceAndroid: true,
            });

            this.loadAudio();
        } catch (e) {
            console.log(e)
        }
    }

    async loadAudio() {
        let mounted = true;
        const {currentIndex, isPlaying, volume} = this.state
        try {
          const playbackInstance = new Audio.Sound()
          const source = this.props.route.params.audio
      
          const status = {
            shouldPlay: isPlaying,
            volume
          }
      
          playbackInstance.setOnPlaybackStatusUpdate(this.onPlaybackStatusUpdate)     
          await playbackInstance.loadAsync(source, status, false)
          if(mounted) {
            this.setState({playbackInstance})
          }
        } catch (e) {
            console.log(e)
        }
        return () => mounted = false;
    }
      
    onPlaybackStatusUpdate = status => {
        this.setState({
            isBuffering: status.isBuffering
        })
    }

    handlePlayPause = async () => {
        const { isPlaying, playbackInstance } = this.state
        isPlaying ? await playbackInstance.pauseAsync() : await playbackInstance.playAsync()
    
        this.setState({
          isPlaying: !isPlaying
        })
    }

    // async componentWillUnmount() {
    //     await this.sound.unloadAsync().then(() => {
    //         console.log('******** sound unloaded ********');
    //         // this.props.onComplete(this.state.playbackInstance);
    //       });
    // }
    

    render () {
        const params = this.props.route.params
        return (
            <View>
                <StatusBar hidden />
                <View style={appLogoContainer}>
                    <Image 
                        style={appLogo}
                        source={require('./images/SensibleLogo.png')}/>
                </View>
                <View>
                    <View /* screen title */ > 
                        <Text style={pageTitle}>
                            {params.title}
                        </Text>
                    </View>
                    <Image source={params.image} style={styles.guideImage} />

                    <View style={styles.controls}>
                        {/* <TouchableOpacity style={styles.control} onPress={() => alert('pressed back')}>
                            <Ionicons name='ios-skip-backward' size={48} color='#444' />
                        </TouchableOpacity> */}
                        <TouchableOpacity style={styles.control} onPress={this.handlePlayPause}>
                            {this.state.isPlaying ? (
                                <Ionicons name='ios-pause' size={48} color={colors.blue} />
                                ) : (
                                <Ionicons name='ios-play-circle' size={48} color={colors.blue} />
                            )}
                        </TouchableOpacity>
                        {/* <TouchableOpacity style={styles.control} onPress={() => alert('pressed forward')}>
                            <Ionicons name='ios-skip-forward' size={48} color='#444' />
                        </TouchableOpacity> */}
                    </View>

                    <View>
                        <Text style={[page, styles.desc]}>
                            {params.desc}{"\n"}
                        </Text>
                        <Text style={[page, styles.desc]}>
                            <Text style={{fontWeight:"bold"}}>Length: </Text>{params.time}
                        </Text>
                        <Text style={styles.desc}>
                            <Text style={{fontWeight:"bold"}}>Last Modified: </Text> {params.date}
                        </Text>
                        <Text style={styles.desc}>
                            <Text style={{fontWeight:"bold"}}>Tags: </Text> 
                            {params.tags.map((tag, index) => (<Text key={tag}>{(index ? ', ' : '') + tag}</Text>))}
                        </Text>
                    </View>
                </View>
            </View>
        )
    };
};


const styles = StyleSheet.create({
    guideImage: {
        height: 200,
        width: 200,
        alignSelf: "center",
        marginTop: '2%',
        marginBottom: '2%',
    },
    desc: {
        fontSize: fontStyles.regularText,
        textAlign: "left",
        paddingRight: '5%',
        paddingLeft: '5%',
    },
    control: {
        alignSelf: "center",
        marginBottom: '2%'
    }
});



