// searchScreen.js

import { StatusBar } from 'expo-status-bar';
import React from 'react';
import { StyleSheet, Text, View, ScrollView, Image, TextInput, TouchableOpacity } from 'react-native';
import { Picker } from '@react-native-picker/picker'
import {colors, appLogo, fontStyles, pageTitle, page, appLogoContainer} from './styles/themes'
import moment from 'moment';

export default class SearchScreen extends React.Component {
    //put all the visual elements in the return below, style everything in the StyleSheet or use themes.js
    data = [
        {
            id: 1,
            title: "Guide #1",
            time: "24:30",
            description: "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.",
            uri: require('./images/cosmicperspective.jpg'),
            audio: require('./audio/cosmicperspective-demo.mp4'),
            tags: ["Relaxation", "Peace"],
            date: moment('20001005T020000-0700'),
        },
        {
            id: 2,
            title: "Guide #2",
            time: "12:30",
            description: "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.",
            uri: require('./images/cosmicperspective.jpg'),
            audio: require('./audio/cosmicperspective-demo.mp4'),
            // date: new Date('05 October 2011 14:48 UTC'),
            tags: ["Relaxation"],
            date: moment('20011005T020000-0700'),
        },
        {
            id: 3,
            title: "Guide #3",
            time: "15:30",
            description: "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.",
            uri: require('./images/cosmicperspective.jpg'),
            audio: require('./audio/cosmicperspective-demo.mp4'),
            tags: ["Peace"],
            // date: new Date('05 October 2011 14:48 UTC'),
            date: moment('20021005T020000-0700'),
        },
        {
            id: 4,
            title: "Guide #4",
            time: "20:00",
            description: "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.",
            uri: require('./images/cosmicperspective.jpg'),
            audio: require('./audio/cosmicperspective-demo.mp4'),
            tags: ["Relaxation", "Peace"],
            // date: new Date('05 October 2011 14:48 UTC'),
            date: moment('20031005T020000-0700'),
        },
        {
            id: 5,
            title: "Guide #5",
            time: "32:00",
            description: "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.",
            uri: require('./images/cosmicperspective.jpg'),
            audio: require('./audio/cosmicperspective-demo.mp4'),
            tags: [""],
            // date: new Date('05 October 2011 14:48 UTC'),
            date: moment('20201005T020000-0700'),
        },
        {
            id: 6,
            title: "Guide #6",
            time: "25:00",
            description: "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.",
            uri: require('./images/cosmicperspective.jpg'),
            audio: require('./audio/cosmicperspective-demo.mp4'),
            tags: ["Stress"],
            // date: new Date('05 October 2011 14:48 UTC'),
            date: moment('20191005T020000-0700'),
        },
    ]


    constructor(props) {
        super(props);
        this.state = { 
            data: this.data,
            filter: 'new-old',
            search: '',
         }
    }

    filterList(list) {
        // filter based on entered search
        if (this.state.search != ''){
            return list.filter((listItem) => listItem.title.toLowerCase().includes(this.state.search.toLowerCase()) ||
                listItem.description.toLowerCase().includes(this.state.search.toLowerCase()),
            );
        }
        // filter based on selected filter 
        //most recent at the top
        if (this.state.filter == "new-old") {
            return list.slice().sort((a, b) => moment(b.date) - moment(a.date));
        }
        //oldest to newest
        if (this.state.filter == "old-new") {
            return list.slice().sort((a, b) => moment(a.date) - moment(b.date));
        }
        // sort by a theme
        if (this.state.filter == "theme-relax") {
            return list.filter((listItem) => listItem.tags.includes("Relaxation"));
        }
        if (this.state.filter == "theme-stress") {
            return list.filter((listItem) => listItem.tags.includes("Stress"));
        }
        if (this.state.filter == "theme-peace") {
            return list.filter((listItem) => listItem.tags.includes("Peace"));
        }
        // sort alphabetically by title
        if (this.state.filter == "program") {
            return list.slice().sort((a, b) => a.title.localeCompare(b.title));
        }
    }


    render(){
        // const list = this.state.data;

        const guideList = this.filterList(this.state.data).map((guide, index) => (
            <TouchableOpacity 
                key={guide.id}
                style={styles.guide}
                //onPress, navigate to the page to open this up to show more information and play button
                onPress={() => this.props.navigation.navigate('Guide', {
                    id: guide.id,
                    image: guide.uri,
                    title: guide.title,
                    desc: guide.description,
                    time: guide.time,
                    audio: guide.audio,
                    tags: guide.tags,
                    date: guide.date.format("MM/DD/YYYY")
                })}> 
                <Image
                    style={styles.guideImage}
                    source={guide.uri}
                />
                <View style={styles.guideText}>
                    <View style={styles.guideHeader}>
                        <Text 
                            style={styles.guideTitleText}>
                            {guide.title}
                        </Text>
                        <Text 
                            style={styles.timeText}>
                            {guide.time}
                        </Text>
                    </View>
                    <Text style={styles.guideDescription}>
                        {guide.description.slice(0, 70)}
                    </Text>
                    <Text style={styles.guideDescription}>
                        Last Modified: {guide.date.format("MM/DD/YYYY")}
                    </Text>
                    <Text 
                        style={styles.guideDescription}>
                        Tags: {guide.tags.map((tag, index) => (<Text key={tag}>{(index ? ', ' : '') + tag}</Text>))}
                    </Text>
                </View>
            </TouchableOpacity>
        ))
        
        return (
            <View>
                <View style={appLogoContainer}>
                    <Image 
                        style={appLogo}
                        source={require('./images/SensibleLogo.png')}/>
                </View>
                <StatusBar hidden />
                <ScrollView style={page}>
                    <View /* screen title */ > 
                        <Text style={pageTitle}>
                            Search
                        </Text>
                    </View>
                    <View>
                        <View style={styles.searchBar}> 
                            <TextInput style = {styles.textSearch}
                                underlineColorAndroid = "transparent"
                                placeholder = "Search..."
                                placeholderTextColor = "grey"
                                onChangeText = {(search) => this.setState({search: search})}
                            />
                        </View>
                        <View>
                                <Text style={{alignSelf: "center", marginBottom: 5, fontSize: fontStyles.regularText}}>Filter By...</Text>
                                <Picker 
                                    selectedValue = {this.state.filter} 
                                    onValueChange = {(itemValue, itemIndex) => this.setState({filter: itemValue})}
                                    style={{ marginTop: 0}}
                                    mode = {'dropdown'}
                                    itemStyle={{fontSize: fontStyles.regularText}}>
                                    <Picker.Item label = "Newest to Oldest" value = "new-old" />
                                    <Picker.Item label = "Oldest to Newest" value = "old-new" />
                                    <Picker.Item label = "Program (A-Z)" value = "program" />
                                    <Picker.Item label = "Theme: Relaxation" value = "theme-relax" />
                                    <Picker.Item label = "Theme: Stress" value = "theme-stress" />
                                    <Picker.Item label = "Theme: Peace" value = "theme-peace" />
                                </Picker>
                            </View>
                        <View style={styles.guideList}>
                            {guideList}
                        </View>

                    </View>

                </ScrollView>
            </View>
        )
    };
};

const styles = StyleSheet.create({
    searchBar: {
        // flexDirection: "row",
        // justifyContent: "center",
        alignSelf: 'center',
        // padding: "20%",
        // padding: '4%',
        // height: '50%',
        width: '50%',
        // marginLeft: '10%',
        padding: '2%',
        marginTop: '2%',
        borderColor: '#B2EAF7',
        borderWidth: 1,
        marginBottom: '2%'
    },
    textSearch: {
        color: 'black',
    },
    text: {
        fontSize: fontStyles.regularText,
        alignSelf: 'center',
        color: 'red',
     },
     dropdown: {
        // paddingLeft: "50%",
        // paddingRight: "50%"
     },

    //guide list styles
    guideList: {
        flexDirection: "column",
        justifyContent: "center",
        marginBottom: '35%'
    },
    guide: {
        flexDirection: "row",
        padding: '3%',
        marginLeft: '5%',
        marginRight: '5%',
        marginBottom: '3%',
        marginTop: '3%',
        backgroundColor: colors.lightBlue,
    },
    guideHeader: {
        flexDirection: "row",
        justifyContent: "space-between",
        marginRight: "20%"
    },
    guideTitleText: {
        fontWeight: "bold", 
        fontSize: fontStyles.subTitleText,
        color: colors.darkGrey,
    },
    timeText: {
        fontStyle: "italic", 
        fontSize: fontStyles.subTitleText,
        color: colors.darkGrey,
        marginRight: '5%'
    },
    guideImage: {
        height: 75,
        width: 75,
        marginRight: 10,
        alignSelf: "center"
    },
    guideDescription: {
        marginTop: "2%",
        marginRight: "30%",
        fontSize: fontStyles.regularText,
        color: colors.darkGrey,
    }
})